@@ -993,11 +993,11 @@ static void winexe_out_pipe_got_data(struct tevent_req *subreq)
 		  nt_errstr(status));
 
 	if (NT_STATUS_EQUAL(status, NT_STATUS_PIPE_DISCONNECTED)) {
-		subreq = cli_close_send(
-			state,
-			state->ev,
-			state->cli,
-			state->out_pipe);
+		subreq = cli_close_send(state,
+					state->ev,
+					state->cli,
+					state->out_pipe,
+					0);
 		if (tevent_req_nomem(subreq, req)) {
 			return;
 		}
@@ -1206,11 +1206,11 @@ static void winexe_in_pipe_written(struct tevent_req *subreq)
 
 	if (NT_STATUS_EQUAL(status, NT_STATUS_PIPE_DISCONNECTED) ||
 	    state->close_requested) {
-		subreq = cli_close_send(
-			state,
-			state->ev,
-			state->cli,
-			state->in_pipe);
+		subreq = cli_close_send(state,
+					state->ev,
+					state->cli,
+					state->in_pipe,
+					0);
 		if (tevent_req_nomem(subreq, req)) {
 			return;
 		}
@@ -1275,11 +1275,8 @@ static bool winexe_in_pipe_close(struct tevent_req *req)
 
 	TALLOC_FREE(state->fd_read_req);
 
-	subreq = cli_close_send(
-		state,
-		state->ev,
-		state->cli,
-		state->in_pipe);
+	subreq =
+		cli_close_send(state, state->ev, state->cli, state->in_pipe, 0);
 	if (subreq == NULL) {
 		return false;
 	}
@@ -1597,11 +1594,11 @@ static void winexe_ctrl_got_read(struct tevent_req *subreq)
 	TALLOC_FREE(subreq);
 
 	if (NT_STATUS_EQUAL(status, NT_STATUS_PIPE_DISCONNECTED)) {
-		subreq = cli_close_send(
-			state,
-			state->ev,
-			state->cli,
-			state->ctrl_pipe);
+		subreq = cli_close_send(state,
+					state->ev,
+					state->cli,
+					state->ctrl_pipe,
+					0);
 		if (tevent_req_nomem(subreq, req)) {
 			return;
 		}
@@ -1695,7 +1692,7 @@ static void winexe_ctrl_got_read(struct tevent_req *subreq)
 		return;
 	}
 
-	ret = sscanf(state->ctrl_inbuf, "version 0x%x\n", &return_code);
+	ret = sscanf(state->ctrl_inbuf, "return_code %x\n", &return_code);
 	if (ret == 1) {
 		state->return_code = return_code;
 		return;
